@@ -41,6 +41,8 @@ nltk.download('stopwords')
 nltk.download('wordnet')
 nltk.download('punkt')
 nltk.download('averaged_perceptron_tagger')
+nltk.download('popular')
+nltk.download('words')
 # Constants
 # POS (Parts Of Speech) for: nouns, adjectives, verbs and adverbs
 DI_POS_TYPES = {'NN': 'n', 'JJ': 'a', 'VB': 'v', 'RB': 'r'}
